import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import buttonStyles from '../Tokens/button';

const noWrap = `
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
`;

const primaryStyle = props => `
  background-color: ${props.theme.button.primary.backgroundColor};
  border-color: ${props.theme.button.primary.borderColor};
  color: ${props.theme.button.primary.color};
  &:hover {
    background-color: ${props.theme.button.primary.hover.backgroundColor};
    border-color: ${props.theme.button.primary.hover.borderColor};
    color: ${props.theme.button.primary.hover.color};
  }
  &:focus {
    background-color: ${props.theme.button.primary.focus.backgroundColor};
    border-color: ${props.theme.button.primary.focus.borderColor};
    color: ${props.theme.button.primary.focus.color};
  }
  &:disabled {
    background-color: ${props.theme.button.primary.disabled.backgroundColor};
    border-color: ${props.theme.button.primary.disabled.borderColor};
    color: ${props.theme.button.primary.disabled.color};
  }
`;

const standardStyle = props => `
  background-color: ${props.theme.button.standard.backgroundColor};
  border-color: ${props.theme.button.standard.borderColor};
  color: ${props.theme.button.standard.color};
  &:hover {
    background-color: ${props.theme.button.standard.hover.backgroundColor};
    border-color: ${props.theme.button.standard.hover.borderColor};
    color: ${props.theme.button.standard.hover.color};
  }
  &:focus {
    background-color: ${props.theme.button.standard.focus.backgroundColor};
    border-color: ${props.theme.button.standard.focus.borderColor};
    color: ${props.theme.button.standard.focus.color};
  }
  &:disabled {
    background-color: ${props.theme.button.standard.disabled.backgroundColor};
    border-color: ${props.theme.button.standard.disabled.borderColor};
    color: ${props.theme.button.standard.disabled.color};
  }
`;

const SButton = styled.button`
  outline: 0;
  cursor: pointer;
  border-radius: ${props => props.theme.button.borderRadius};
  font-size: ${props => props.theme.button.fontSize};
  line-height: ${props => props.theme.button.lineHeight};
  font-weight: ${props => props.theme.button.fontWeight};
  min-width: ${props => props.theme.button.minWidth};
  padding-top: ${props => props.theme.button.paddingTop};
  padding-bottom: ${props => props.theme.button.paddingBottom};
  padding-left: ${props => props.theme.button.paddingLeft};
  padding-right: ${props => props.theme.button.paddingRight};
  margin-top: ${props => props.theme.button.marginTop};
  margin-bottom: ${props => props.theme.button.marginBottom};
  border-width: ${props => props.theme.button.borderWidth};
  border-style: ${props => props.theme.button.borderStyle};
  ${props => props.type === 'primary' ? primaryStyle(props) : standardStyle(props)};
  ${props => !props.noWrap && noWrap};
`;

function Button(props) {
  if (props.href !== null && props.href !== undefined) {
    return React.createElement(
      'a',
      { href: props.href },
      React.createElement(SButton, props)
    );
  }
  return React.createElement(SButton, props);
}

Button.propTypes = process.env.NODE_ENV !== "production" ? {
  href: PropTypes.string,
  noWrap: PropTypes.bool,
  theme: PropTypes.object,
  type: PropTypes.string
} : {};

Button.defaultProps = {
  href: null,
  type: 'standard',
  theme: {
    button: _extends({}, buttonStyles.base, {
      standard: _extends({}, buttonStyles.standard),
      primary: _extends({}, buttonStyles.primary)
    })
  }
};

export default Button;